@@ -1,16 +1,22 @@
 # -*- coding: utf-8 -*-
 """
-detection module
+detection module for heads
 """
 
 import cv2
+import numpy as np
 import grpc
 
 from sail_utils import LOGGER
 from sail_utils.cv.head.config import (
     DEFAULT_TIME_OUT,
+    DST_SIZE,
     THRESHOLD
 )
+from sail_utils.cv.base import (
+    _Detector,
+    _Mapper
+)
 from sail_utils.cv.head.protobuf import (
     inference_head_detection_pb2,
     inference_head_detection_pb2_grpc
@@ -19,7 +25,7 @@ from sail_utils.cv.head.protobuf import (
 
 def _unary_detect(stub, img, time_out=None):
     request = inference_head_detection_pb2. \
-        ObjectDetectionRequest(request_info="called by Python client",
+        ObjectDetectionRequest(request_info=__name__,
                                model_version=0)
     img_encode = cv2.imencode('.jpg', img)[1]
     request.image_data = img_encode.tobytes()
@@ -34,57 +40,27 @@ def _unary_detect(stub, img, time_out=None):
     return rtn_value
 
 
-class _Mapper:
-
-    def __init__(self, src: int, dst: int):
-        self._src = src
-        self._dst = dst
-        LOGGER.info(f"mapper from <{self._src}> to <{self._dst}>")
-
-    def resize(self, img):
-        """
-        resize pic to destination size
-        :param img:
-        :return:
-        """
-        return cv2.resize(img, (self._dst, self._dst), interpolation=cv2.INTER_AREA)
-
-    def __call__(self, bbox):
-        scale = self._src / self._dst
-        return [
-            int(bbox[0] * scale),
-            int(bbox[1] * scale),
-            int(bbox[2] * scale),
-            int(bbox[3] * scale),
-        ]
-
-    def __str__(self):
-        return f"source: <{self._src} - destination: <{self._dst}>"
-
-
 def _format(resp, epoch: int, threshold: float, calibrator: _Mapper):
     results = []
-    for i, res in enumerate(resp):
+    for res in resp:
         if res.score >= threshold:
             box = res.box
             xmin = box.xmin
             ymin = box.ymin
             xmax = box.xmax
             ymax = box.ymax
-            score = res.score
 
             results.append(
                 dict(
-                    id=i + 1,
                     location=calibrator([int(xmin), int(ymin), int(xmax), int(ymax)]),
                     time_stamp=epoch,
-                    score=score
+                    score=res.score
                 )
             )
     return sorted(results, key=lambda x: x['time_stamp'])
 
 
-class Detector:
+class HeadDetector(_Detector):
     """
     class for detection functionality
     """
@@ -92,16 +68,12 @@ class Detector:
     def __init__(self,
                  server: str,
                  src_size: int,
-                 dst_size: int = 416,
+                 dst_size: int = DST_SIZE,
                  threshold: float = THRESHOLD,
                  timeout: float = DEFAULT_TIME_OUT):
-        self._server = server
-        self._threshold = threshold
-        self._mapper = _Mapper(src_size, dst_size)
-        self._timeout = timeout
-        LOGGER.info(f"detector at: <{self._server}> with threshold <{self._threshold:.2f}>")
+        super().__init__(server, src_size, dst_size, threshold, timeout)
 
-    def detect(self, img, epoch):
+    def detect(self, img: np.ndarray, epoch) -> list:
         """
         detect on one image
         :param img:
@@ -113,6 +85,3 @@ class Detector:
             stub = inference_head_detection_pb2_grpc.HeadDetectionStub(channel)
             resp = _unary_detect(stub, img, self._timeout)
             return _format(resp, epoch, self._threshold, self._mapper)
-
-    def __str__(self):
-        return f"mapper: {self._mapper}\nserver: {self._server}"
