@@ -70,3 +70,6 @@ class OSSUtility:
             next_marker = results.next_marker
             for result in results.object_list:
                 yield result.key
+
+    def exists(self, key) -> bool:
+        return self._bucket.object_exists(key)
